Skip to contents

This data set contains a long-form adjacency object derived from the Meta Social Connectedness Index for the Nordic countries. The object is formatted for use with DiseasyRegions.

Meta Social Connectedness Index. Data accessed from the Humanitarian Data Exchange. Retrieved June 15, 2026. See https://data.humdata.org/dataset/social-connectedness-index and https://ai.meta.com/ai-for-good/docs/methodology-social-connectedness-index/.

Details

The data set consists of a data.frame with three columns:

  • from: The origin country.

  • to: The destination country.

  • adjacency: The contacts from from allocated to to.

The adjacency values are two-way contact between regions and should be interpreted a type of "infection-flow" matrix.