Skip to contents

This data set contains the unique NUTS region identifiers represented in demography_nuts after truncating to the latest available year and removing rows with missing population values.

Source: 10.2908/demo_r_pjangrp3. Retrieved June 15, 2026. Population on 1 January by age group, sex and NUTS 3 region

Details

This object is derived from demography_nuts, which is a modified version of Eurostat dataset demo_r_pjangrp3. Eurostat is not responsible for the modifications made to the source data.

Author

Rasmus Skytte Randløv rske@ssi.dk