Meta Social Connectedness Index as adjacency for NUTS 3 regions (Nordics)
Source:R/data.R
adjacency_meta_nordic_nuts.RdThis data set contains a long-form adjacency object derived from the Meta Social Connectedness Index
for NUTS 3 regions in then Nordic countries. The object is formatted for use with DiseasyRegions and
DiseasyRegionsNuts.
Meta Social Connectedness Index. Data accessed from the Humanitarian Data Exchange. Retrieved June 15, 2026. See https://data.humdata.org/dataset/social-connectedness-index and https://ai.meta.com/ai-for-good/docs/methodology-social-connectedness-index/.
Details
The data set consists of a data.frame with three columns:
from: The origin NUTS 3 region.to: The destination NUTS 3 region.adjacency: The contacts fromfromallocated toto.
The adjacency values are two-way contact between regions and should be interpreted a type of "infection-flow" matrix.