This data set population data for 176 geographical regions in 1-year age-groups to allow transformation of the contact matrices into other age cuts.
U.S. Census Bureau. (n.d.). International Database: World Population Estimates and Projections. U.S. Department of Commerce. Retrieved May 29, 2026, from https://data.census.gov/
Details
This product uses the Census Bureau Data API but is not endorsed or certified by the Census Bureau.
Author
Rasmus Skytte Randløv rske@ssi.dk